////////////////////////////////////////////////////////////////////////////////
// The BAR_Search() function will perform a Google search for us. The two
// parameters that get passed in are the event that triggered this function
// call, and the type of search to perform.
////////////////////////////////////////////////////////////////////////////////
function BAR_Search(event, type)
{
    // This variable will hold the URL we will browse to
    var URL = "";

    // This variable will tell us whether our search box is empty or not
    var isEmpty = false;

    // Get a handle to our search terms box (the <menulist> element)
    var searchTermsBox = document.getElementById("BAR-SearchTerms");
    
    // Get the value in the search terms box, trimming whitespace as necessary
    // See the BAR_TrimString() function farther down in this file for details
    // on how it works.
    var searchTerms = BAR_TrimString(searchTermsBox.value);

    if(searchTerms.length == 0) // Is the search terms box empty?
        isEmpty = true;         // If so, set the isEmpty flag to true
    else                        // If not, convert the terms to a URL-safe string
        searchTerms = BAR_ConvertTermsToURI(searchTerms);

    // Now switch on whatever the incoming type value is
    // If the search box is empty, we simply redirect the user to the appropriate
    // place at the Google website. Otherwise, we search for whatever they entered.

    switch(type)
    {
    case "motor":
        if(isEmpty) { URL = "http://www.motors.ebay.com/"; }
        else        { URL = "http://motors.search.ebay.com/search/search.dll?satitle=" + searchTerms; }
        break;
    case "ebay":
    default:
        if(isEmpty) { URL = "http://www.ebay.com/"; }
        else        { URL = "http://search.ebay.com/search/search.dll?satitle=" + searchTerms; }
        break;

    }
    
    // Load the URL in the browser window using the BAR_LoadURL function
    BAR_LoadURL('ebay',URL);
}

////////////////////////////////////////////////////////////////////////////////
// The BAR_TrimString() function will trim all leading and trailing whitespace
// from the incoming string, and convert all runs of more than one whitespace
// character into a single space. The altered string gets returned.
////////////////////////////////////////////////////////////////////////////////
function BAR_TrimString(string)
{
    // If the incoming string is invalid, or nothing was passed in, return empty
    if (!string)
        return "";

    string = string.replace(/^\s+/, ''); // Remove leading whitespace
    string = string.replace(/\s+$/, ''); // Remove trailing whitespace

    // Replace all whitespace runs with a single space
    string = string.replace(/\s+/g, ' ');

    return string; // Return the altered value
}

////////////////////////////////////////////////////////////////////////////////
// The BAR_ConvertTermsToURI() function converts an incoming string of search
// terms to a safe value for passing into a URL.
////////////////////////////////////////////////////////////////////////////////
function BAR_ConvertTermsToURI(terms)
{
    // Create an array to hold each search term
    var termArray = new Array();

    // Split up the search term string based on the space character
    termArray = terms.split(" ");

    // Create a variable to hold our resulting URI-safe value
    var result = "";

    // Loop through the search terms
    for(var i=0; i<termArray.length; i++)
    {
        // All search terms (after the first one) are to be separated with a '+'
        if(i > 0)
            result += "+";

        // Encode each search term, using the built-in Firefox function
        // encodeURIComponent().
        result += encodeURIComponent(termArray[i]);
    }

    return result; // Return the result
}

////////////////////////////////////////////////////////////////////////////////
// The BAR_LoadURL() function loads the specified URL in the browser.
////////////////////////////////////////////////////////////////////////////////
function BAR_LoadURL(type,url)
{ 

    if (type == 'ebay') url = 'http://rover.ebay.com/rover/1/711-1751-2978-71/1?AID=5463217&PID=2776664+&mpre=' + url;
    else  url = url;

    window._content.document.location = unescape(url); 
    window.content.focus();
}

////////////////////////////////////////////////////////////////////////////////
// The BAR_KeyHandler() function checks to see if the key that was pressed
// is the [Enter] key. If it is, a web search is performed.
////////////////////////////////////////////////////////////////////////////////
function BAR_KeyHandler(event)
{
    // Was the key that was pressed [ENTER]? If so, perform a web search.
    if(event.keyCode == event.DOM_VK_RETURN)
        BAR_Search(event, 'ebay');
}

////////////////////////////////////////////////////////////////////////////////
// The BAR_Populate() function places dynamically generated menu items inside
// our toolbar's search box drop-down menu. Although this sample isn't very
// practical, it is provided as an example of how dynamic menu population works.
////////////////////////////////////////////////////////////////////////////////
function BAR_Populate()
{
	// Get the menu element that we will be working with
	var menu = document.getElementById("BAR-SearchTermsMenu");

	// Clean up whatever is currently in the menu
	for(var i=menu.childNodes.length - 1; i>=0; i--) {
		menu.removeChild(menu.childNodes.item(i));
	}

	// This string contains 5 "search terms", each separated by two pipes (||)
	var terms = "wii||xBox 360||PS3||Music||ipod||Movies||Sport||Tickets||Video Games";

	// Create an array based on the terms in the string above
	var termArray = new Array();
	termArray = terms.split("||");

	// Load the search terms into our menu
	for(var i=0; i<termArray.length; i++)
	{
		var tempItem = null;
		tempItem = document.createElement("menuitem");
		tempItem.setAttribute("label", termArray[i]);
		tempItem.setAttribute("tooltiptext", "Dynamic Item " + (i+1));
		menu.appendChild(tempItem);
	}
}